@@ -5,7 +5,10 @@ from enum import Enum
 
 
 _slot_tag_map_ct: dict[Enum, tuple[Enum]] = {
-    LoadoutSlot.AGENT_CT: (TagsInternalName.AGENTS_BROKEN_FANG, TagsInternalName.AGENTS_SHATTERED_WEB),
+    LoadoutSlot.AGENT_CT: (
+        TagsInternalName.AGENTS_BROKEN_FANG,
+        TagsInternalName.AGENTS_SHATTERED_WEB,
+    ),
     LoadoutSlot.KNIFE_CT: (TagsInternalName.KNIVES,),
     LoadoutSlot.M4A4: (TagsInternalName.M4A4, TagsInternalName.M4A1_S),
     LoadoutSlot.M4A1_S: (TagsInternalName.M4A4, TagsInternalName.M4A1_S),
@@ -37,7 +40,10 @@ _slot_tag_map_ct: dict[Enum, tuple[Enum]] = {
 }
 
 _slot_tag_map_t: dict[Enum, tuple[Enum]] = {
-    LoadoutSlot.AGENT_T: (TagsInternalName.AGENTS_BROKEN_FANG, TagsInternalName.AGENTS_SHATTERED_WEB),
+    LoadoutSlot.AGENT_T: (
+        TagsInternalName.AGENTS_BROKEN_FANG,
+        TagsInternalName.AGENTS_SHATTERED_WEB,
+    ),
     LoadoutSlot.KNIFE_T: (TagsInternalName.KNIVES,),
     LoadoutSlot.GLOCK_18: (TagsInternalName.GLOCK_18,),
     LoadoutSlot.P250_T: (TagsInternalName.P250,),
@@ -72,52 +78,73 @@ _slot_tag_map: dict[Enum, tuple[Enum]] = {
 
 # Market hash names of T agents
 _agents_t: tuple[str] = (
-    'Sir Bloody Miami Darryl | The Professionals',
-    'Sir Bloody Loudmouth Darryl | The Professionals',
-    'Sir Bloody Darryl Royale | The Professionals',
-    'Sir Bloody Skullhead Darryl | The Professionals',
-    'Sir Bloody Silent Darryl | The Professionals',
+    "Sir Bloody Miami Darryl | The Professionals",
+    "Sir Bloody Loudmouth Darryl | The Professionals",
+    "Sir Bloody Darryl Royale | The Professionals",
+    "Sir Bloody Skullhead Darryl | The Professionals",
+    "Sir Bloody Silent Darryl | The Professionals",
     "'The Doctor' Romanov | Sabre",
-    'The Elite Mr. Muhlik | Elite Crew',
-    'Number K | The Professionals',
-    'Safecracker Voltzmann | The Professionals',
-    'Blackwolf | Sabre',
-    'Rezan The Ready | Sabre',
-    'Rezan the Redshirt | Sabre',
-    'Prof. Shahmat | Elite Crew',
-    'Getaway Sally | The Professionals',
-    'Little Kev | The Professionals',
-    'Osiris | Elite Crew',
-    'Slingshot | Phoenix',
-    'Dragomir | Sabre',
-    'Maximus | Sabre',
-    'Street Soldier | Phoenix',
-    'Dragomir | Sabre Footsoldier',
-    'Enforcer | Phoenix',
-    'Ground Rebel | Elite Crew',
-    'Soldier | Phoenix',
+    "The Elite Mr. Muhlik | Elite Crew",
+    "Number K | The Professionals",
+    "Safecracker Voltzmann | The Professionals",
+    "Blackwolf | Sabre",
+    "Rezan The Ready | Sabre",
+    "Rezan the Redshirt | Sabre",
+    "Prof. Shahmat | Elite Crew",
+    "Getaway Sally | The Professionals",
+    "Little Kev | The Professionals",
+    "Osiris | Elite Crew",
+    "Slingshot | Phoenix",
+    "Dragomir | Sabre",
+    "Maximus | Sabre",
+    "Street Soldier | Phoenix",
+    "Dragomir | Sabre Footsoldier",
+    "Enforcer | Phoenix",
+    "Ground Rebel | Elite Crew",
+    "Soldier | Phoenix",
+    "Vypa Sista of the Revolution | Guerrilla Warfare",
+    "'Medium Rare' Crasswater | Guerrilla Warfare",
+    "Crasswater The Forgotten | Guerrilla Warfare",
+    "Elite Trapper Solman | Guerrilla Warfare",
+    "Bloody Darryl The Strapped | The Professionals",
+    "Arno The Overgrown | Guerrilla Warfare",
+    "Col. Mangos Dabisi | Guerrilla Warfare",
+    "Trapper | Guerrilla Warfare",
+    "Trapper Aggressor | Guerrilla Warfare",
+    "Mr. Muhlik | Elite Crew",
 )
 
 # Market hash names of CT agents
 _agents_ct: tuple[str] = (
-    'Special Agent Ava | FBI',
-    'Lt. Commander Ricksaw | NSWC SEAL',
+    "Special Agent Ava | FBI",
+    "Lt. Commander Ricksaw | NSWC SEAL",
     "Cmdr. Mae 'Dead Cold' Jamison | SWAT",
-    '1st Lieutenant Farlow | SWAT',
+    "1st Lieutenant Farlow | SWAT",
     "'Two Times' McCoy | USAF TACP",
-    'Michael Syfers | FBI Sniper',
+    "Michael Syfers | FBI Sniper",
     "'Two Times' McCoy | TACP Cavalry",
     "John 'Van Healen' Kask | SWAT",
     "Sergeant Bombson | SWAT",
     "'Blueberries' Buckshot | NSWC SEAL",
     "Buckshot | NSWC SEAL",
-    'Markus Delrow | FBI HRT',
-    'Chem-Haz Specialist | SWAT',
-    '3rd Commando Company | KSK',
-    'Seal Team 6 Soldier | NSWC SEAL',
-    'Bio-Haz Specialist | SWAT',
-    'B Squadron Officer | SAS',
-    'Operator | FBI SWAT',
+    "Markus Delrow | FBI HRT",
+    "Chem-Haz Specialist | SWAT",
+    "3rd Commando Company | KSK",
+    "Seal Team 6 Soldier | NSWC SEAL",
+    "Bio-Haz Specialist | SWAT",
+    "B Squadron Officer | SAS",
+    "Operator | FBI SWAT",
+    "Chef d'Escadron Rouchard | Gendarmerie Nationale",
+    "Cmdr. Frank 'Wet Sox' Baroud | SEAL Frogman",
+    "Cmdr. Davida 'Goggles' Fernandez | SEAL Frogman",
+    "Chem-Haz Capitaine | Gendarmerie Nationale",
+    "Lieutenant Rex Krikey | SEAL Frogman",
+    "Officer Jacques Beltram | Gendarmerie Nationale",
+    "Lieutenant 'Tree Hugger' Farlow | SWAT",
+    "Sous-Lieutenant Medic | Gendarmerie Nationale",
+    "Primeiro Tenente | Brazilian 1st Battalion",
+    "D Squadron Officer | NZSAS",
+    "Aspirant | Gendarmerie Nationale",
 )
 
 _equippable: tuple = (
@@ -126,8 +153,7 @@ _equippable: tuple = (
     TagsInternalName.KNIVES,
     TagsInternalName.MUSIC_KITS,
     TagsInternalName.AGENTS_BROKEN_FANG,
-    TagsInternalName.AGENTS_SHATTERED_WEB
-
+    TagsInternalName.AGENTS_SHATTERED_WEB,
 )
 
 
@@ -165,7 +191,7 @@ class Item:
         for attr in dir(self):
             if not attr.startswith("_"):
                 yield attr, getattr(self, attr)
-    
+
     def __repr__(self):
         return str(dict(self))
 
@@ -203,7 +229,10 @@ class Item:
         for slot, tag_names in needed_map.items():
             for tag in self.tags:
                 if (internal_name := tag["internal_name"]) in tag_names:
-                    if internal_name == TagsInternalName.AGENTS_BROKEN_FANG or internal_name == TagsInternalName.AGENTS_SHATTERED_WEB:
+                    if (
+                        internal_name == TagsInternalName.AGENTS_BROKEN_FANG
+                        or internal_name == TagsInternalName.AGENTS_SHATTERED_WEB
+                    ):
                         if side == TeamSide.CT and self.market_hash_name in _agents_ct:
                             slots.append(slot.value)
                         elif side == TeamSide.T and self.market_hash_name in _agents_t:
